<?php

namespace WPIS;

class EstateProperties {

    static public $supportedLanguages = ['fr', 'nl', 'en'];

    static public $postTypeMetas;

    public function __construct(){

        self::$postTypeMetas = [
            [
                'id' => 'options',
                'label' => __('Immo Sync Options', 'wpis'),
                'icon' => 'fa-cogs',
                'callback' => 'wpisMetaboxBodyOptions',
                'fields' =>  [
                    [
                        'field' => 'locked',
                        'label' => __('Ne pas mettre à jour', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'undeletable',
                        'label' => __('Ne pas supprimer', 'wpis'),
                        'type'  => 'boolean'
                    ],
                ],
            ],
            [
                'id' => 'general',
                'label' => __('General', 'wpis'),
                'icon' => 'fa-home',
                'callback' => 'wpisMetaboxBodyGeneral',
                'fields' =>  [
                    [
                        'field' => 'id',
                        'label' => __('ID du bien', 'wpis'),
                        'type'  => 'readonly'
                    ],
                    [
                        'field' => 'name',
                        'label' => __('Titre du bien', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                    [
                        'field' => 'reference',
                        'label' => __('Référence', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'category.label',
                        'label' => __('Catégorie', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                    [
                        'field' => 'subcategory.label',
                        'label' => __('Sous-catégorie', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                    [
                        'field' => 'purpose.label',
                        'label' => __('Transaction', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                    [
                        'field' => 'status.label',
                        'label' => __('Status de la transaction', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                    [
                        'field' => 'links.virtualVisit',
                        'label' => __('Lien visite virtuelle', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'links.video',
                        'label' => __('Lien vidéo', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'links.3dModel',
                        'label' => __('Lien model 3D', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'links.appointment',
                        'label' => __('Lien rendez-vous', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'properties.hasChildren',
                        'label' => __('Projet parent', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'properties.hasParent',
                        'label' => __('Projet enfant', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'properties.parentId',
                        'label' => __('Projet parent ID', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'properties.isFavorite',
                        'label' => __('Mise en avant', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'properties.isFurnished',
                        'label' => __('Bien meublé', 'wpis'),
                        'type'  => 'boolean'
                    ]
                ]
            ],
            [
                'id' => 'finance',
                'label' => __('Finance', 'wpis'),
                'icon' => 'fa-euro-sign',
                'callback' => 'wpisMetaboxBodyFinance',
                'fields' =>  [
                    [
                        'field' => 'finance.price',
                        'label' => __('Prix', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'finance.priceChangedAt',
                        'label' => __('Prix changé le', 'wpis'),
                        'type'  => 'date'
                    ],
                    [
                        'field' => 'finance.availability',
                        'label' => __('Disponibilité', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                    [
                        'field' => 'finance.currency',
                        'label' => __('Devise', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'finance.annuityMonthly',
                        'label' => __('Rente mensuelle', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'finance.cadastre',
                        'label' => __('Cadastre', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'finance.offer',
                        'label' => __('Faie offre à partir de', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'building.constructionYear',
                        'label' => __('Date de construction', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'building.renovationYear',
                        'label' => __('Date de rénovation', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'building.orientation',
                        'label' => __('Orientation du batiment', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                    [
                        'field' => 'building.state',
                        'label' => __('Etat du batiment', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                ]
            ],
            [
                'id' => 'surfaces',
                'label' => __('Surfaces', 'wpis'),
                'icon' => 'fa-expand',
                'callback' => 'wpisMetaboxBodySurface',
                'fields' =>  [
                    [
                        'field' => 'areas.total',
                        'label' => __('Superficie totale', 'wpis'),
                        'type'  => 'number'

                    ],
                    [
                        'field' => 'areas.ground',
                        'label' => __('Superficie terrain', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.garden',
                        'label' => __('Superficie jardin', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.living',
                        'label' => __('Superficie Salle de séjour', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.diningroom',
                        'label' => __('Superficie Salle à manger', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.kitchen',
                        'label' => __('Superficie cuisine', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.bathroom',
                        'label' => __('Superficie salle de bain', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.cellar',
                        'label' => __('Superficie cave', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.washroom',
                        'label' => __('Superficie buandrie', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.dressing',
                        'label' => __('Superficie dressing', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.bedroom1',
                        'label' => __('Superficie Chambre 1', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.bedroom2',
                        'label' => __('Superficie Chambre 2', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.bedroom3',
                        'label' => __('Superficie Chambre 3', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.bedroom4',
                        'label' => __('Superficie Chambre 4', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.bedroom5',
                        'label' => __('Superficie Chambre 5', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.showroom',
                        'label' => __('Superficie Showroom', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.storage',
                        'label' => __('Superficie Stockage', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.terrace',
                        'label' => __('Superficie Terrace', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.manufacturing',
                        'label' => __('Superficie Manufacturing', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'areas.displayWindow',
                        'label' => __('Superficie Vitrine', 'wpis'),
                        'type'  => 'number'
                    ]
                ]
            ],
            [
                'id' => 'energy',
                'label' => __('Rapports énergétique', 'wpis'),
                'icon' => 'fa-leaf',
                'callback' => 'wpisMetaboxBodyEnergy',
                'fields' =>  [
                    [
                        'field' => 'energy.epcCode',
                        'label' => __('Code unique PEB', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'energy.epcLabel',
                        'label' => __('Classe énergétique PEB', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'energy.epcValue',
                        'label' => __('Valeur énergétique E-SPEC kWh/m²/an', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'energy.epcTotal',
                        'label' => __('Valeur énergétique total E-Total Kwh/an', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'energy.gazEmit',
                        'label' => __('Valeur d\'émission de gaz Kg CO2/an', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'energy.heatingType',
                        'label' => __('Type de chauffage', 'wpis'),
                        'type'  => 'text',
                        'translatable' => true
                    ],
                    [
                        'field' => 'energy.solarElectricity',
                        'label' => __('Energie solaire', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'energy.electricityConformity',
                        'label' => __('Conformité éléctricité', 'wpis'),
                        'type'  => 'boolean'
                    ]
                ]
            ],
            [
                'id' => 'address',
                'label' => __('Adresse', 'wpis'),
                'icon' => 'fa-location-arrow',
                'callback' => 'wpisMetaboxBodyAddress',
                'fields' =>  [
                    [
                        'field' => 'address.street',
                        'label' => __('Rue', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'address.number',
                        'label' => __('Numéro', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'address.box',
                        'label' => __('Boite', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'address.zip',
                        'label' => __('Code postal', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'address.city',
                        'label' => __('Ville', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'address.country',
                        'label' => __('Pays', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'address.longitude',
                        'label' => __('Longitude', 'wpis'),
                        'type'  => 'text'
                    ],
                    [
                        'field' => 'address.latitude',
                        'label' => __('Latitude', 'wpis'),
                        'type'  => 'text'
                    ]
                ]
            ],
            [
                'id' => 'proximity',
                'label' => __('Proximité', 'wpis'),
                'icon' => 'fa-route',
                'callback' => 'wpisMetaboxBodyProximity',
                'fields' =>  [
                    [
                        'field' => 'proximity.highway',
                        'label' => __('Autoroute', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.transports',
                        'label' => __('Transports en commun', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.station',
                        'label' => __('Gare', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.bus',
                        'label' => __('Bus', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.metro',
                        'label' => __('Métro', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.tram',
                        'label' => __('Tram', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.school',
                        'label' => __('Ecole', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.stores',
                        'label' => __('Magasins', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.sportCenter',
                        'label' => __('Centre sportif', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'proximity.beach',
                        'label' => __('Plage', 'wpis'),
                        'type'  => 'number'
                    ]
                ]
            ],
            [
                'id' => 'commodities',
                'label' => __('Commodités', 'wpis'),
                'icon' => 'fa-star',
                'callback' => 'wpisMetaboxBodyCommodities',
                'fields' =>  [
                    [
                        'field' => 'configuration.floorCurrent',
                        'label' => __('Etage du bien', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'configuration.floorTotal',
                        'label' => __('Nombre d\'étage(s)', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'configuration.bedrooms',
                        'label' => __('Nombre de chambre(s)', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'configuration.kitchens',
                        'label' => __('Type de cuisine', 'wpis'),
                        'type'  => 'string'
                    ],
                    [
                        'field' => 'configuration.toilets',
                        'label' => __('Nombre de toilette(s)', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'configuration.bathrooms',
                        'label' => __('Nombre de salle d\'eau(s)', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'configuration.garages',
                        'label' => __('Nombre de garage(s)', 'wpis'),
                        'type'  => 'number'
                    ],
                    [
                        'field' => 'configuration.terraces',
                        'label' => __('Nombre de terrasse(s)', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'configuration.cave',
                        'label' => __('Cave', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'configuration.parking',
                        'label' => __('Parking', 'wpis'),
                        'type'  => 'boolean'
                    ],
                    [
                        'field' => 'configuration.garden',
                        'label' => __('Jardin', 'wpis'),
                        'type'  => 'boolean'
                    ]
                ]
            ],
            [
                'id' => 'files',
                'label' => __('Fichiers liés', 'wpis'),
                'icon' => 'fa-file-pdf',
                'callback' => 'wpisMetaboxBodyFiles',
                'fields' =>  [
                    [
                        'field' => 'files',
                        'label' => __('Documents', 'wpis'),
                        'type'  => 'file-collection'
                    ]
                ]
            ],
            [
                'id' => 'hidden',
                'label' => __(null, 'wpis'),
                'icon' => null,
                'callback' => null,
                'fields' =>  [
                    ['field' => 'id'],
                    ['field' => 'created_at'],
                    ['field' => 'purpose.id'],
                    ['field' => 'status.id'],
                    ['field' => 'description.base', 'translatable' => true],
                    ['field' => 'description.short', 'translatable' => true],
                    ['field' => 'description.long', 'translatable' => true],
                    ['field' => 'ameneties.generic', 'translatable' => true],
                    ['field' => 'ameneties.custom', 'translatable' => true],
                    ['field' => 'agency.id'],
                    ['field' => 'agency.name'],
                    ['field' => 'agency.addressFormatted'],
                    ['field' => 'agent.firstname'],
                    ['field' => 'agent.lastname'],
                    ['field' => 'agent.email'],
                    ['field' => 'agent.phone'],
                    ['field' => 'agent.role'],
                    ['field' => 'agent.picture']
                ]
            ]
        ];

    }
}
